@@ -1,6 +1,6 @@
 """Abstract base classes for conveniently associating parameters with classes"""
 
-from typing import Callable, MutableMapping, List, Union
+from typing import Callable, MutableMapping, List, Union, Dict
 from abc import ABC
 from copy import copy
 from pydantic import create_model, BaseModel, Field
@@ -244,6 +244,37 @@ class YAMLConfig(ABC):
                 continue
             instance.apply_parameters(**kwargs)
 
+    @classmethod
+    def validate_parameters(cls, **kwargs) -> Dict:
+        """
+        Method for validating parameters against their type cast. Defined yaml parameters will be referenced for their
+        type-cast in order to perform the validation. If there are any errors, they should be included in the output
+        dictionary with an appropriate error string indicating what went wrong.
+
+        :param kwargs: keyword arguments to validate
+        :return: dictionary of any error messages and their associated parameter
+        """
+        out = {}
+        for name, params in cls.yaml_parameters.items():
+            key_name = params.kwarg_alias or name
+            # if value is defined and instance has this attribute, update the instance value
+            if key_name in kwargs:
+                val = kwargs[key_name]
+                if val is not None and params.typecast is not None:
+                    try:
+                        # try type casting the value
+                        params.typecast(val)
+                    except Exception as e:
+                        # if there was an error, report that error as a string in the outgoing dictionary
+                        out[key_name] = str(e)
+        # pass through kwargs to sub-instances
+        if type(cls.sub_configurations) is dict:
+            for deriv_class in cls.sub_configurations.values():
+                out.update(
+                    deriv_class.validate_parameters(**kwargs)
+                )
+        return out
+
     @classmethod
     def get_pydantic_model(cls) -> BaseModel:
         """creates a pydantic model from the YAMLConfig instance"""
