@@ -153,7 +153,12 @@ class Registry:
 
             if value.startswith('${'):
                 env_var, default_value = self.parse_environment_variable(value)
-                return os.environ.get(env_var, default_value)
+                value = os.environ.get(env_var, default_value)
+
+                if isinstance(value, str) and value != '':
+                    return yaml.safe_load(value)
+
+                return value
 
             if value.startswith('$'):
                 if '.' in value:
